@@ -85,7 +85,7 @@ static const int TOOLTIPS_LEN = 256;
 #define BORDER 6
 
 /* newsreader$B%G!<%?$N<hF@(B,$B99?7$N$?$a$N%m%C%/(B */
-static pthread_mutex_t newsreader_mutex = PTHREAD_MUTEX_INITIALIZER;
+/* static pthread_mutex_t newsreader_mutex = PTHREAD_MUTEX_INITIALIZER;*/
 
 /* GetFeedList$B$X$N:FF~$rKI$0(B */
 static pthread_mutex_t getfeedlist_mutex = PTHREAD_MUTEX_INITIALIZER;
@@ -111,6 +111,12 @@ const gint INIT_LABEL_WIDTH = 300;
 const gint INIT_UPDATE_MIN = 60;
 const gint INIT_UPDATE_SEC = 10;
 
+enum{
+	ORDER_DESC = -1,
+    ORDER_NONE,
+	ORDER_ASC,
+};
+
 static feeddata_t*
 create_new_feeddata()
 {
@@ -174,6 +180,8 @@ copy_outlineList(newsreader_t* newsreader)
 	outline_t* pOutlineSrc;
 	outline_t* pOutlineDst;
 
+	DEBUG_PRINT("start");
+
 	for(pList = newsreader->poOutlineList; pList; pList = pList->next){
 		if(!(pOutlineSrc = (outline_t*)pList->data)){
 			DEBUG_PRINT("copy_outlinelist fatal error");
@@ -188,6 +196,8 @@ copy_outlineList(newsreader_t* newsreader)
 		pOutlineDst->iValidHours = pOutlineSrc->iValidHours;
 		pOutlineList = g_list_append(pOutlineList, pOutlineDst);
 	}	
+
+	DEBUG_PRINT("end");
 	
 	return pOutlineList;
 }
@@ -210,6 +220,14 @@ free_outlineList(GList* pOutlineList)
 	return;
 }
 
+/* $B%"%$%F%`%j%9%H$N%=!<%H$K;HMQ(B */
+/* use for item list sort */
+static gint 
+item_list_compare(item_t* item_a, item_t* item_b, gpointer user_data)
+{
+	return (gint)(GPOINTER_TO_INT(user_data) * (item_a->tmModified - item_b->tmModified));
+}
+
 static void
 StoreFeedList2File(newsreader_t* newsreader)
 {
@@ -510,7 +528,6 @@ clear_feed_list_menu(newsreader_t* newsreader)
 {
 	GtkWidget *menuFeedList;
 
-
 	if(!(menuFeedList = gtk_menu_item_get_submenu(newsreader->wItmFeedList))){
 		return;
 	}
@@ -522,7 +539,6 @@ clear_feed_list_menu(newsreader_t* newsreader)
 	g_list_free(newsreader->poMenuItemList);
 	newsreader->poMenuItemList = NULL;
 
-
 	return;
 }
 
@@ -580,7 +596,7 @@ getFaviconPixbuf(newsreader_t* newsreader, const gchar* pchUri)
 }
 
 /* $B%]%C%W%"%C%W%a%K%e!<$N99?7(B */
-static int
+static gboolean
 update_feed_list_menu(newsreader_t* newsreader)
 {
 	GList *pFeedList, *pItemList;
@@ -597,6 +613,8 @@ update_feed_list_menu(newsreader_t* newsreader)
 	GtkWidget* itmItem;
 	int iFeedNo, iItemNo;
 
+	XFCE_PANEL_LOCK();
+
 	clear_feed_list_menu(newsreader);
 
 	menuFeedList = gtk_menu_new();
@@ -713,11 +731,24 @@ update_feed_list_menu(newsreader_t* newsreader)
 
 	DEBUG_PRINT("update_feed_list_menu End");
 
-	return iFeedNo;
+	//	return iFeedNo;
+
+	XFCE_PANEL_UNLOCK();
+
+	return FALSE;
+}
+
+/* $B%]%C%W%"%C%W%a%K%e!<$r(Bgtk main loop$B$K<B9T$7$F$b$&(B */
+static void
+update_popupmenu_register(newsreader_t* newsreader)
+{
+	g_idle_add_full(G_PRIORITY_HIGH_IDLE, (GSourceFunc)update_feed_list_menu, newsreader, NULL);
+
+	return;
 }
 
 /* Feed$B%j%9%H$N@hF,$KI,$:2C$($k(BFeed */
-static feeddata_t*  CreateStaticFeed(void)
+static feeddata_t*  create_static_feed(void)
 {
 
 	feeddata_t* pFeedData = NULL;
@@ -900,6 +931,11 @@ GetFeed(char* buff, int len)
 		g_warning("!!! get feed");
 	}
 
+	if(pfeed && pfeed->items){
+		pfeed->items = g_list_sort_with_data(pfeed->items, (GCompareDataFunc)item_list_compare, 
+								   GINT_TO_POINTER(ORDER_DESC));
+	}
+	
 	xmlUnlinkNode(root);
 	xmlFreeNode(root);
 	xmlFreeDoc(doc);
@@ -950,7 +986,7 @@ set_new_flag_all(feeddata_t* pFeedData, gboolean bIsNew)
 
 /* $B%U%#!<%I%j%9%H$h$j%U%#!<%I%G!<%?$r<hF@$9$k(B */
 static gpointer
-GetFeedList(newsreader_t* newsreader)
+get_feed_list(newsreader_t* newsreader)
 {
 	char* buff;
 	int feedNo = 0;
@@ -978,12 +1014,10 @@ GetFeedList(newsreader_t* newsreader)
 	pthread_mutex_lock(&getfeed_mutex);
 
 	NEWSREADER_LOCK();
-	DEBUG_PRINT("copy_outlineList start");
 	pOutlineList = copy_outlineList(newsreader);
-	DEBUG_PRINT("copy_outlineList end");
 	NEWSREADER_UNLOCK();
 
-	poNewList = g_list_append(poNewList, CreateStaticFeed());
+	poNewList = g_list_append(poNewList, create_static_feed());
 
 	feedNo++;
 	outline_t* poOutline;
@@ -1105,7 +1139,8 @@ GetFeedList(newsreader_t* newsreader)
 	}
 	g_list_free(poOldList);
 
-	update_feed_list_menu(newsreader);
+	//	update_feed_list_menu(newsreader);
+	update_popupmenu_register(newsreader);
 
 	NEWSREADER_UNLOCK();
 
@@ -1131,7 +1166,8 @@ static gboolean SetUpdateFeedTimer(void *p_newsreader)
   }
 
   /*g_thread_create((GThreadFunc)GetFeedList, newsreader, FALSE, NULL);*/
-  pthread_create(&thread, NULL, (void*)GetFeedList, (void*)newsreader);
+  pthread_create(&thread, NULL, (void*)get_feed_list, (void*)newsreader);
+  pthread_detach(thread);
 
   newsreader->iFeedTimerID = g_timeout_add (newsreader->feedUpdateMin * 60 * 1000,
 												  (GtkFunction) SetUpdateFeedTimer, newsreader);
@@ -2255,7 +2291,8 @@ dragedfeed_append_to_list(newsreader_t* newsreader)
 	newsreader->g_pCurFeed = NULL;
 	newsreader->g_pCurItem = NULL;
 
-	update_feed_list_menu(newsreader);
+	//update_feed_list_menu(newsreader);
+	update_popupmenu_register(newsreader);
 
 	g_free(newsreader->pchURI);
 
@@ -2336,6 +2373,7 @@ void on_wLblItem_drag_drop( GtkWidget        *widget,
 	gtk_drag_finish(context, TRUE, TRUE, time_);
 
 	pthread_create(&thread, NULL, (void*)dragedfeed_append_to_list, (void*)newsreader);
+	pthread_detach(thread);
 
 	return;
 
@@ -2396,7 +2434,7 @@ create_newsreader_control (Control * control)
 	newsreader->strItemFontName = g_string_new(pango_font_description_to_string(pango_context_get_font_description(gtk_widget_create_pango_context(GTK_WIDGET(newsreader->wLblItem)))));
 
 	newsreader->g_pFeedList = NULL;
-	newsreader->g_pFeedList = g_list_append(newsreader->g_pFeedList, CreateStaticFeed());
+	newsreader->g_pFeedList = g_list_append(newsreader->g_pFeedList, create_static_feed());
 	newsreader->g_pCurFeed = NULL;
 	newsreader->g_pCurItem = NULL;
 
