@@ -44,7 +44,9 @@
  */
 
 #ifdef DEBUG
-#define DEBUG_PRINT(...) g_message(__VA_ARGS__)
+#define DEBUG_PRINT(...) { printf("%s(%u): ",__func__,__LINE__); \
+                         printf(__VA_ARGS__); printf("\n"); }
+//#define DEBUG_PRINT(...)
 #else
 #define DEBUG_PRINT(...)
 #endif
@@ -65,10 +67,13 @@ print_item(xmlDocPtr doc, xmlNode * node)
 	for(cur = node; cur != NULL ; cur = cur->next){
 		if (cur->type != XML_ELEMENT_NODE)
 			continue;
-		if(xmlStrcmp(cur->name, "title") == 0)
+		if(xmlStrcmp(cur->name, "title") == 0){
 			DEBUG_PRINT("title: %s\n", xmlNodeListGetString(doc, cur->children, 1));
-		else if(xmlStrcmp(cur->name, "link") == 0)
+		}
+		else if(xmlStrcmp(cur->name, "link") == 0){
 			DEBUG_PRINT("link: %s\n", xmlNodeListGetString(doc, cur->children, 1));
+		}
+		
 	}
 }
 
@@ -101,7 +106,7 @@ copy_items(GList* pItemList)
 	GList* pList;
 	
 	if(!pItemList){
-		g_warning("copy_items faild");
+		DEBUG_PRINT("copy_items faild");
 		return NULL;
 	}
 	
@@ -110,17 +115,16 @@ copy_items(GList* pItemList)
 		if(!pItem){
 			continue;
 		}
-		
-		printf("pItem = %p\n", pItem);
 
 		pNewItem = create_new_item();
+
 		if(pItem->title){
 			pNewItem->title = g_string_new(pItem->title->str);
 		}
 		
 		if(pItem->url){		
 			pNewItem->url = g_string_new(pItem->url->str);
-			g_warning("%s", pItem->url->str);
+			DEBUG_PRINT("%s", pItem->url->str);
 		}
 		
 		pNewItem->tmModified = pItem->tmModified;
@@ -138,7 +142,7 @@ copy_feed(feed_t* pFeed)
 	feed_t* pNewFeed = NULL;
 
 	if(!pFeed){
-		g_warning("copy_feed faild");
+		DEBUG_PRINT("copy_feed faild");
 		return NULL;
 	}
 	
@@ -241,7 +245,7 @@ get_atom_entry(feed_t* pFeed, xmlDocPtr doc, xmlNode* node)
 	}
 
 	if(!pItem->title || !pItem->url){
-		g_warning("invalid item");
+		DEBUG_PRINT("invalid item");
 		free_item(pItem);
 	}
 	else{
@@ -334,7 +338,7 @@ get_rss10_item(feed_t* pfeed, xmlDocPtr doc, xmlNode* node)
 	}
 
 	if(!pitem->title || !pitem->url){
-		g_warning("invalid item");
+		DEBUG_PRINT("invalid item");
 		free_item(pitem);
 	}
 	else{
@@ -390,7 +394,7 @@ get_rss20_item(feed_t* pFeed, xmlDocPtr doc, xmlNode* node)
 	}
 
 	if(!pItem->title || !pItem->url){
-		g_warning("invalid item");
+		DEBUG_PRINT("invalid item");
 		free_item(pItem);
 	}
 	else{
@@ -582,12 +586,12 @@ getFeedList_XBEL(xmlDocPtr doc, GList* poList)
 	xmlNode *cur = NULL;
 
 	if(!(root = xmlDocGetRootElement(doc))){
-		g_warning("failed getting root element");
+		DEBUG_PRINT("failed getting root element");
 		return poList;
 	}
 
 	if (xmlStrcmp(root->name, (const xmlChar *)"xbel") != 0) {
-		g_warning("Not XBEL");
+		DEBUG_PRINT("Not XBEL");
 		xmlUnlinkNode(root);
 		xmlFreeNode(root);
 		return poList;
@@ -746,12 +750,12 @@ getOutlineList(xmlDocPtr doc, GList* poList)
 	xmlChar* value;
 
 	if(!(root = xmlDocGetRootElement(doc))){
-		g_warning("failed getting root element");
+		DEBUG_PRINT("failed getting root element");
 		return poList;
 	}
 
 	if (xmlStrcmp(root->name, (const xmlChar *)"opml")) {
-		g_warning("Not OPML");
+		DEBUG_PRINT("Not OPML");
 		xmlUnlinkNode(root);
 		xmlFreeNode(root);
 		return poList;
@@ -883,22 +887,22 @@ get_favicon_path(xmlDocPtr doc)
 	gchar* retStr;
 
 	if(!doc){
-		g_warning("doc is null");
+		DEBUG_PRINT("doc is null");
 		return NULL;
 	}
 
 	if(!(node = doc->children)){
-		g_warning("node is null\n");
+		DEBUG_PRINT("node is null\n");
 		return NULL;
 	}
 	
 	if(!(node = get_node(node, "html"))){
-		g_warning("not found html tag\n");
+		DEBUG_PRINT("not found html tag\n");
 		return NULL;
 	}
 
 	if(!(node = get_node(node->children, "head"))){
-		g_warning("not found head tag\n");
+		DEBUG_PRINT("not found head tag\n");
 		return NULL;
 	}
 
